@@ -277,7 +277,7 @@ for (var k = 0; k < bonds.length; k++) {
 var bond = bonds[k];
 var index = bond.index;
 var atom2;
-if (bsDone.get (index) || bond.getCovalentOrder () != 2 || JS.SmilesSearch.isRingBond (this.ringSets, i, (atom2 = bond.getOtherAtomNode (atom1)).getIndex ())) continue;
+if (bsDone.get (index) || bond.getCovalentOrder () != 2 || JS.SmilesSearch.isRingBond (this.ringSets, null, i, (atom2 = bond.getOtherAtomNode (atom1)).getIndex ())) continue;
 bsDone.set (index);
 var nCumulene = 0;
 var a10 = atom1;
@@ -400,7 +400,7 @@ bondNext = bond;
 }}
 var atomNext = (bondNext == null ? null : bondNext.getOtherAtomNode (atom));
 var orderNext = (bondNext == null ? 0 : bondNext.getCovalentOrder ());
-if (isAromatic || orderNext == 2 && nH > 1 || atomNext != null && JS.SmilesSearch.isRingBond (this.ringSets, atomIndex, atomNext.getIndex ())) {
+if (isAromatic || orderNext == 2 && nH > 1 || atomNext != null && JS.SmilesSearch.isRingBond (this.ringSets, null, atomIndex, atomNext.getIndex ())) {
 sp2Atoms = null;
 }var stereo =  new Array (7);
 if (stereoFlag < 7 && bondPrev != null) {
