@@ -2035,8 +2035,11 @@ var x = mp.getX ();
 var sArg = (args.length > 0 ? JS.SV.sValue (args[0]) : tok == 1275068932 ? "" : "\n");
 switch (args.length) {
 case 0:
-case 1:
 break;
+case 1:
+if (args[0].tok == 1073742335) {
+return mp.addX (JS.SV.getVariable (JU.PT.getTokens (x.asString ())));
+}break;
 case 2:
 if (x.tok == 7) break;
 if (tok == 1275069447) {
